#include <iostream>
#include <chrono>

bool is_prime(int64_t n)
{
   for(int64_t i = 2; n >= i*i; i++)
   {
      if((n % i) == 0) return false;
   }
   return true;
}

namespace
{
   constexpr int num_tests = 10000;
   
   constexpr int xstep = 1;
   constexpr int xmin = 1;
   constexpr int xmax = 1000000;
}

double time_measurement(int64_t n)
{
   auto t0 = std::chrono::high_resolution_clock::now();
   for(int i = 0; i < num_tests; i++)
   {
      is_prime(n);
   }
   auto t1 = std::chrono::high_resolution_clock::now();
   return std::chrono::duration_cast<std::chrono::nanoseconds>(t1-t0).count() / (double)num_tests;
}

int main()
{
   for(int64_t x = xmin; xmax >= x; x += xstep)
   {
      std::cout << x << "\t\t" << time_measurement(x) << "\n";
      std::cout.flush();
   }
}
